aboutsummaryrefslogtreecommitdiffstats
path: root/tests
diff options
context:
space:
mode:
authorIvan Solovev <ivan.solovev@qt.io>2023-07-20 19:01:35 +0200
committerIvan Solovev <ivan.solovev@qt.io>2023-07-25 12:16:31 +0200
commit6ffcaefbe16e165f4ebe7f7a87005187d6f5c5a7 (patch)
tree8149a56c4d034bbec94910f314a565a9a8508adf /tests
parente90b39053b26a96a37d0f9d28640862121b52dc1 (diff)
Update tests and docker scripts to reflect the provisioning updates
The californium docker container is updated, and now provides a different binary to run. This patch adjusts the tests and docker script: * update the docker script to call the proper binary * update the number of resources exposed by the californium server * update the expected returned tokens to be uppercase Task-number: QTBUG-114798 Pick-to: 6.6 6.5 Change-Id: I733793cc472769e433144a08b8f02f0120f6f29b Reviewed-by: Alex Blasche <alexander.blasche@qt.io> Reviewed-by: Qt CI Bot <qt_ci_bot@qt-project.org> Reviewed-by: Dimitrios Apostolou <jimis@qt.io> Reviewed-by: Sona Kurazyan <kurazyan.sona@gmail.com>
Diffstat (limited to 'tests')
-rw-r--r--tests/auto/qcoapclient/tst_qcoapclient.cpp9
-rwxr-xr-xtests/testserver/californium/californium.sh2
2 files changed, 6 insertions, 5 deletions
diff --git a/tests/testserver/californium/californium.sh b/tests/testserver/californium/californium.sh
index f1d4e3c..bbc9c61 100755
--- a/tests/testserver/californium/californium.sh
+++ b/tests/testserver/californium/californium.sh
@@ -4,4 +4,4 @@
set -ex
-java -jar /root/src/californium/demo-apps/run/cf-plugtest-server-1.1.0-SNAPSHOT.jar &
+java -jar /root/src/californium/demo-apps/run/cf-plugtest-server-3.8.0.jar &
diff --git a/tests/auto/qcoapclient/tst_qcoapclient.cpp b/tests/auto/qcoapclient/tst_qcoapclient.cpp
index ccdd01d..16a5110 100644
--- a/tests/auto/qcoapclient/tst_qcoapclient.cpp
+++ b/tests/auto/qcoapclient/tst_qcoapclient.cpp
@@ -545,7 +545,8 @@ void tst_QCoapClient::multipleRequests()
QCOMPARE(replies[i]->responseCode(), QtCoap::ResponseCode::Content);
QByteArray replyData = replies[i]->readAll();
const auto token = "token" + QByteArray::number(i);
- QVERIFY(replyData.contains(token.toHex()));
+ // The californium server now returns the hex token in uppercase
+ QVERIFY(replyData.contains(token.toHex().toUpper()));
}
}
@@ -835,14 +836,14 @@ void tst_QCoapClient::discover_data()
QTest::addColumn<int>("resourceNumber");
QTest::addColumn<QtCoap::SecurityMode>("security");
// Californium test server exposes 29 resources
QTest::newRow("discover")
<< QUrl(testServerHost())
- << 29
+ << 31
<< QtCoap::SecurityMode::NoSecurity;
QTest::newRow("discover_secure")
<< QUrl(testServerHost())
- << 29
+ << 31
<< QtCoap::SecurityMode::PreSharedKey;
}
@@ -835,14 +836,14 @@ void tst_QCoapClient::discover_data()
QTest::addColumn<int>("resourceNumber");
QTest::addColumn<QtCoap::SecurityMode>("security");
- // Californium test server exposes 29 resources
+ // Californium test server exposes 31 resources
QTest::newRow("discover")
<< QUrl(testServerHost())